@@ -321,7 +321,7 @@ fr_command_unstuff_finalize (GObject *object)
 GType
 fr_command_unstuff_get_type ()
 {
-        static guint type = 0;
+        static GType type = 0;
 
         if (! type) {
                 GTypeInfo type_info = {
