@@ -49,7 +49,7 @@ static void fr_command_finalize    (GObject *object);
 GType
 fr_command_get_type ()
 {
-        static guint type = 0;
+        static GType type = 0;
 
         if (! type) {
                 GTypeInfo type_info = {
@@ -209,6 +209,15 @@ fr_command_init (FRCommand *comm)
 	comm->e_filename = NULL;
 	comm->file_list = NULL;
 	comm->fake_load = FALSE;
+
+	comm->propCanModify = TRUE;
+	comm->propAddCanUpdate = FALSE;
+	comm->propAddCanReplace = FALSE;
+	comm->propExtractCanAvoidOverwrite = FALSE;
+	comm->propExtractCanSkipOlder = FALSE;
+	comm->propExtractCanJunkPaths = FALSE;
+	comm->propPassword = FALSE;
+	comm->propTest = FALSE;
 }
 
 
