@@ -54,8 +54,9 @@ struct _FRCommand
 
 	/*<protected>*/
 
-	/* properties the command support. */
+	/* properties the command supports. */
 
+	uint propCanModify : 1;
 	uint propAddCanUpdate : 1;
 	uint propAddCanReplace : 1;
 	uint propExtractCanAvoidOverwrite : 1;
