@@ -100,7 +100,7 @@ _gtk_message_dialog_new (GtkWindow        *parent,
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
 	
-	hbox = gtk_hbox_new (FALSE, 6);
+	hbox = gtk_hbox_new (FALSE, 24);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
 	
 	gtk_box_pack_start (GTK_BOX (hbox), image,
@@ -221,14 +221,16 @@ _gtk_request_dialog_run (GtkWindow        *parent,
 
 	label = gtk_label_new (message);	
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
-	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
+	gtk_label_set_selectable (GTK_LABEL (label), FALSE);
+	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.0);
 
 	entry = gtk_entry_new ();
+	gtk_widget_set_size_request (entry, 250, -1);
 	gtk_entry_set_activates_default (GTK_ENTRY (entry), TRUE);
 	gtk_entry_set_max_length (GTK_ENTRY (entry), max_length);
 	gtk_entry_set_text (GTK_ENTRY (entry), default_value);
 	
-	hbox = gtk_hbox_new (FALSE, 6);
+	hbox = gtk_hbox_new (FALSE, 24);
 	vbox = gtk_vbox_new (FALSE, 6);
 
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
@@ -310,7 +312,7 @@ _gtk_yesno_dialog_new (GtkWindow        *parent,
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
 	
-	hbox = gtk_hbox_new (FALSE, 12);
+	hbox = gtk_hbox_new (FALSE, 24);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 6);
 	
 	gtk_box_pack_start (GTK_BOX (hbox), image,
