@@ -351,14 +351,26 @@ prepare_app (poptContext pctx)
 	} 
 
 	default_dir = get_path_from_url (default_url);
-	extract_to_path = get_path_from_url (extract_to);
+	
+	if ((extract_to != NULL) && g_path_is_absolute (extract_to))
+		extract_to_path = get_path_from_url (extract_to);
+	else {
+		char *full_path;
+		char *current_dir = g_get_current_dir ();
+
+		full_path = g_build_filename (current_dir, extract_to, NULL);
+		g_free (current_dir);
+		extract_to_path = get_path_from_url (full_path);
+		g_free (full_path);
+	}
+
         add_to_path = get_path_from_url (add_to);
 
 	if ((add_to != NULL) || (add == 1)) { /* Add files to an archive */
 		FRWindow    *window;
 		GList       *file_list = NULL;
 		const char  *filename;
-		
+
 		window = window_new ();
 		if (default_dir != NULL)
 			window_set_default_dir (window, default_dir);
