@@ -70,6 +70,16 @@ new_archive (GtkWidget *file_sel,
 	else
 		archive_window = window;
 
+	/* Pass the add_after_creation options to the new window. */
+	if (archive_window != window) {
+		archive_window->add_after_creation = window->add_after_creation;
+		if (archive_window->add_after_creation) {
+			archive_window->dropped_file_list = window->dropped_file_list;
+			window->dropped_file_list = NULL;
+		}
+		window->add_after_creation = FALSE;
+	}
+
 	if (window_archive_new (archive_window, path)) {
 		gtk_window_present (GTK_WINDOW (archive_window->app));
 		gtk_widget_destroy (file_sel);
@@ -78,35 +88,13 @@ new_archive (GtkWidget *file_sel,
 }
 
 
-static guint
-opt_menu_get_active_idx (GtkWidget *opt_menu)
-{
-        GtkWidget *item;
-        guint      idx;
-        GList     *scan;
-        GtkWidget *menu;
-
-        menu = gtk_option_menu_get_menu (GTK_OPTION_MENU (opt_menu));
-        item = gtk_menu_get_active (GTK_MENU (menu));
-
-        idx = 0;
-        scan = GTK_MENU_SHELL (menu)->children;
-        while (scan && (item != scan->data)) {
-                idx++;
-                scan = scan->next;
-        }
-
-        return idx;
-}
-
-
 typedef struct {
 	char *name;
 	char *ext;
 } FileTypeDescription;
 
 
-FileTypeDescription type_desc[] = { 
+FileTypeDescription write_type_desc[] = { 
 	{ N_("Automatic"),                             NULL},
 	{ N_("Arj (.arj)"),                            ".arj" },
 	{ N_("Ear (.ear)"),                            ".ear" },
@@ -124,19 +112,17 @@ FileTypeDescription type_desc[] = {
 	{ N_("Zoo (.zoo)"),                            ".zoo" }
 };
 
-static int type_desc_n = sizeof (type_desc) / sizeof (FileTypeDescription);
-
 
 static char *
 get_full_path (GtkWidget *file_sel)
 {
-	GtkWidget   *opt_menu;
+	GtkWidget   *combo_box;
 	char        *full_path;
 	char        *path;
 	const char  *filename;
 	int          file_type_idx;
 
-	opt_menu = g_object_get_data (G_OBJECT (file_sel), "fr_opt_menu");
+	combo_box = g_object_get_data (G_OBJECT (file_sel), "fr_combo_box");
 	path = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (file_sel));
 
 	if ((path == NULL) || (*path == 0))
@@ -148,10 +134,10 @@ get_full_path (GtkWidget *file_sel)
 		return NULL;
 	}
 	
-	file_type_idx = opt_menu_get_active_idx (opt_menu);
+	file_type_idx = gtk_combo_box_get_active (GTK_COMBO_BOX (combo_box));
 	if (file_type_idx > 0) {
 		full_path = g_strconcat (path, 
-					 type_desc[file_type_idx].ext,
+					 write_type_desc[file_type_idx].ext,
 					 NULL);
 		g_free (path);
 	} else {
@@ -271,70 +257,78 @@ new_file_response_cb (GtkWidget *w,
 }
 
 
-static GtkWidget *
-build_file_type_menu (FRWindow *window)
-{
-        GtkWidget *menu;
-        GtkWidget *item;
-	int        i;
-
-        menu = gtk_menu_new ();
-        for (i = 0; i < type_desc_n; i++) {
-                item = gtk_menu_item_new_with_label (_(type_desc[i].name));
-		gtk_widget_show (item);
-                gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
-        }
-
-	return menu;
-}
-
-
 void
 new_archive_cb (GtkWidget *widget, 
 		void      *data)
 {
+	static const char * save_mime_type[] = {
+		"application/x-tar",
+		"application/x-compressed-tar",
+		"application/x-bzip-compressed-tar",
+		"application/x-arj",
+		"application/zip",
+		"application/x-java-archive",
+		"application/x-jar",
+		"application/x-lha",
+		"application/x-rar",
+		"application/x-rar-compressed",
+		"application/x-gzip",
+		"application/x-bzip",
+		"application/x-compress",
+		"application/x-lzop",
+		"application/x-zoo",
+	};
 	FRWindow  *window = data;
 	GtkWidget *file_sel;
 	GtkWidget *hbox;
-	GtkWidget *vbox, *vbox2;
-	GtkWidget *opt_menu;
-	GtkWidget *menu;
+	GtkWidget *combo_box;
+	GtkFileFilter *filter;
+	int i;
 
-	file_sel = gtk_file_chooser_dialog_new (_("New"),
-					        NULL,
-					        GTK_FILE_CHOOSER_ACTION_SAVE,
-					        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					        GTK_STOCK_NEW, GTK_RESPONSE_OK,
-					        NULL);
+	file_sel = gtk_file_chooser_dialog_new (
+			_("New"),
+			GTK_WINDOW (window->app),
+			GTK_FILE_CHOOSER_ACTION_SAVE,
+			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+			GTK_STOCK_NEW, GTK_RESPONSE_OK,
+			NULL);
 
 	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (file_sel),
 					     window->open_default_dir);
 
-	vbox = gtk_vbox_new (FALSE, 0);
-	gtk_file_chooser_set_extra_widget (GTK_FILE_CHOOSER (file_sel), vbox);
+	filter = gtk_file_filter_new ();
+	gtk_file_filter_set_name (filter, _("All archives"));
+	for (i = 0; i < G_N_ELEMENTS (save_mime_type); i++)
+		gtk_file_filter_add_mime_type (filter, save_mime_type[i]);
+	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (file_sel), filter);
+	gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (file_sel), filter);
 
-	vbox2 = gtk_vbox_new (FALSE, 6);
-	gtk_box_pack_start (GTK_BOX (vbox), vbox2, TRUE, TRUE, 6);
+	filter = gtk_file_filter_new ();
+	gtk_file_filter_set_name (filter, _("All files"));
+	gtk_file_filter_add_pattern (filter, "*");
+	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (file_sel), filter);
 
 	/**/
 
-	hbox = gtk_hbox_new (FALSE, 0);
-	gtk_box_pack_start (GTK_BOX (vbox2), hbox, TRUE, TRUE, 0);
+	hbox = gtk_hbox_new (FALSE, 12);
+	gtk_file_chooser_set_extra_widget (GTK_FILE_CHOOSER (file_sel), hbox);
 
 	gtk_box_pack_start (GTK_BOX (hbox), 
 			    gtk_label_new (_("Archive type:")),
 			    FALSE, FALSE, 0);
 
-	opt_menu = gtk_option_menu_new ();
-	menu = build_file_type_menu (window);
-        gtk_option_menu_set_menu (GTK_OPTION_MENU (opt_menu), menu);
-	gtk_widget_show (opt_menu);
-	gtk_box_pack_start (GTK_BOX (hbox), opt_menu, FALSE, FALSE, 12);
+	combo_box = gtk_combo_box_new_text ();
+	for (i = 0; i < G_N_ELEMENTS (write_type_desc); i++)
+		gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box),
+					   _(write_type_desc[i].name));
+	gtk_combo_box_set_active (GTK_COMBO_BOX (combo_box), 0);
+	gtk_box_pack_start (GTK_BOX (hbox), combo_box, TRUE, TRUE, 0);
+	gtk_widget_show_all (hbox);
 	
 	/**/
 
 	g_object_set_data (G_OBJECT (file_sel), "fr_window", window);
-	g_object_set_data (G_OBJECT (file_sel), "fr_opt_menu", opt_menu);
+	g_object_set_data (G_OBJECT (file_sel), "fr_combo_box", combo_box);
 	g_object_set_data (G_OBJECT (window->app), "fr_file_sel", file_sel);
 	
 	g_signal_connect (G_OBJECT (file_sel),
@@ -467,39 +461,72 @@ void
 save_as_archive_cb (GtkWidget *widget, 
 		    void *data)
 {
+	static const char * save_mime_type[] = {
+		"application/x-tar",
+		"application/x-compressed-tar",
+		"application/x-bzip-compressed-tar",
+		"application/x-arj",
+		"application/zip",
+		"application/x-java-archive",
+		"application/x-jar",
+		"application/x-lha",
+		"application/x-rar",
+		"application/x-rar-compressed",
+		"application/x-gzip",
+		"application/x-bzip",
+		"application/x-compress",
+		"application/x-lzop",
+		"application/x-zoo",
+	};
 	FRWindow  *window = data;
 	GtkWidget *file_sel;
 	GtkWidget *hbox;
-	GtkWidget *opt_menu;
-	GtkWidget *menu;
+	GtkWidget *combo_box;
+	GtkFileFilter *filter;
+	int i;
 
-	file_sel = gtk_file_chooser_dialog_new (_("Save"),
-					        NULL,
-					        GTK_FILE_CHOOSER_ACTION_SAVE,
-					        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					        GTK_STOCK_SAVE, GTK_RESPONSE_OK,
-					        NULL);
+	file_sel = gtk_file_chooser_dialog_new (
+			_("Save"),
+			GTK_WINDOW (window->app),
+			GTK_FILE_CHOOSER_ACTION_SAVE,
+			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+			GTK_STOCK_SAVE, GTK_RESPONSE_OK,
+			NULL);
 
 	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (file_sel),
 					     window->open_default_dir);
 
+	filter = gtk_file_filter_new ();
+	gtk_file_filter_set_name (filter, _("All archives"));
+	for (i = 0; i < G_N_ELEMENTS (save_mime_type); i++)
+		gtk_file_filter_add_mime_type (filter, save_mime_type[i]);
+	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (file_sel), filter);
+	gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (file_sel), filter);
+
+	filter = gtk_file_filter_new ();
+	gtk_file_filter_set_name (filter, _("All files"));
+	gtk_file_filter_add_pattern (filter, "*");
+	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (file_sel), filter);
+
 	/**/
 
-	hbox = gtk_hbox_new (FALSE, 0);
+	hbox = gtk_hbox_new (FALSE, 12);
 	gtk_box_pack_start (GTK_BOX (hbox), 
 			    gtk_label_new (_("Archive type:")),
 			    FALSE, FALSE, 0);
-	opt_menu = gtk_option_menu_new ();
-	menu = build_file_type_menu (window);
-        gtk_option_menu_set_menu (GTK_OPTION_MENU (opt_menu), menu);
-	gtk_box_pack_start (GTK_BOX (hbox), opt_menu, FALSE, FALSE, 12);
+	combo_box = gtk_combo_box_new_text ();
+	for (i = 0; i < G_N_ELEMENTS (write_type_desc); i++)
+		gtk_combo_box_append_text (GTK_COMBO_BOX (combo_box),
+					   _(write_type_desc[i].name));
+	gtk_combo_box_set_active (GTK_COMBO_BOX (combo_box), 0);
+	gtk_box_pack_start (GTK_BOX (hbox), combo_box, TRUE, TRUE, 0);
 	gtk_widget_show_all (hbox);
 
 	gtk_file_chooser_set_extra_widget (GTK_FILE_CHOOSER (file_sel), hbox);	
 	/**/
 
 	g_object_set_data (G_OBJECT (file_sel), "fr_window", window);
-	g_object_set_data (G_OBJECT (file_sel), "fr_opt_menu", opt_menu);
+	g_object_set_data (G_OBJECT (file_sel), "fr_combo_box", combo_box);
 	
 	g_signal_connect (G_OBJECT (file_sel),
 			  "response", 
@@ -560,30 +587,35 @@ open_archive_cb (GtkWidget *widget,
 		"application/x-tar",
 		"application/x-compressed-tar",
 		"application/x-bzip-compressed-tar",
+		"application/x-lzop-compressed-tar",
 		"application/x-arj",
 		"application/zip",
-		"application/x-java-archive",
+		"application/x-zip",
 		"application/x-lha",
 		"application/x-rar",
 		"application/x-rar-compressed",
+		"application/x-rpm",
 		"application/x-stuffit",
 		"application/x-gzip",
 		"application/x-bzip",
 		"application/x-compress",
 		"application/x-lzop",
 		"application/x-zoo",
+		"application/x-java-archive",
+		"application/x-jar"
 	};
 	GtkWidget     *file_sel;
 	FRWindow      *window = data;
 	GtkFileFilter *filter;
 	int            i;
 
-	file_sel = gtk_file_chooser_dialog_new (_("Open"),
-					        NULL,
-					        GTK_FILE_CHOOSER_ACTION_OPEN,
-					        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					        GTK_STOCK_OPEN, GTK_RESPONSE_OK,
-					        NULL);
+	file_sel = gtk_file_chooser_dialog_new (
+			_("Open"),
+			GTK_WINDOW (window->app),
+			GTK_FILE_CHOOSER_ACTION_OPEN,
+			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+			GTK_STOCK_OPEN, GTK_RESPONSE_OK,
+			NULL);
 
 	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (file_sel),
 					     window->open_default_dir);
@@ -600,16 +632,6 @@ open_archive_cb (GtkWidget *widget,
 	gtk_file_filter_add_pattern (filter, "*");
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (file_sel), filter);
 
-	for (i = 1; i < G_N_ELEMENTS (type_desc); i++) {
-		char *pattern;
-		filter = gtk_file_filter_new ();
-		gtk_file_filter_set_name (filter, _(type_desc[i].name));
-		pattern = g_strconcat ("*", type_desc[i].ext, NULL);
-		gtk_file_filter_add_pattern (filter, pattern);
-		g_free (pattern);
-		gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (file_sel), filter);
-	}
-
 	/**/
 
 	g_object_set_data (G_OBJECT (file_sel), "fr_window", window);
@@ -661,7 +683,7 @@ copy_or_move_archive_response_cb (GtkWidget    *w,
 				  int           response,
 				  CopyMoveData *data)
 {
-	FRWindow    *window = data->window;;
+	FRWindow    *window = data->window;
 	char        *folder;
 	char        *new_path;
 
@@ -766,16 +788,15 @@ copy_or_move_archive (FRWindow *window,
 	data->copy = copy;
 	data->overwrite = overwrite;
 	data->file_sel = file_sel = 
-		gtk_file_chooser_dialog_new (copy ? _("Copy") : _("Move"),
-					     NULL,
-					     GTK_FILE_CHOOSER_ACTION_SAVE,
-					     GTK_STOCK_CANCEL,
-					     GTK_RESPONSE_CANCEL,
-					     copy ? _("_Copy"): _("_Move"),
-					     GTK_RESPONSE_OK,
-					     NULL);
-	gtk_file_chooser_set_folder_mode (GTK_FILE_CHOOSER (file_sel),
-					  TRUE);
+		gtk_file_chooser_dialog_new (
+		     copy ? _("Copy") : _("Move"),
+		     GTK_WINDOW (window->app),
+		     GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
+		     GTK_STOCK_CANCEL,
+		     GTK_RESPONSE_CANCEL,
+		     copy ? _("_Copy"): _("_Move"),
+		     GTK_RESPONSE_OK,
+		     NULL);
 	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (file_sel),
 					     window->open_default_dir);
  
