@@ -24,9 +24,6 @@
 #define MENU_CALLBACKS_H
 
 
-void   new_window_cb                 (GtkWidget *widget, 
-				      void *data);
-
 void   close_window_cb               (GtkWidget *widget, 
 				      void *data);
 
@@ -63,9 +60,18 @@ void   view_cb                       (GtkWidget *widget,
 void   view_or_open_cb               (GtkWidget *widget, 
 				      void *data);
 
+void   go_home_cb                    (GtkWidget *widget, 
+				      void *data);
+
 void   go_up_one_level_cb            (GtkWidget *widget, 
 				      void *data);
 
+void   go_back_cb                    (GtkWidget *widget, 
+				      void *data);
+
+void   go_forward_cb                 (GtkWidget *widget, 
+				      void *data);
+
 void   set_list_mode_flat_cb         (GtkWidget *widget, 
 				      void *data);
 
@@ -120,4 +126,16 @@ void   view_toolbar_cb               (GtkWidget *widget,
 void   view_statusbar_cb             (GtkWidget *widget, 
 				      void      *data);
 
+void   rename_cb                     (GtkWidget *widget, 
+				      void *data);
+
+void   cut_cb                        (GtkWidget *widget, 
+				      void *data);
+
+void   copy_cb                       (GtkWidget *widget, 
+				      void *data);
+
+void   paste_cb                      (GtkWidget *widget, 
+				      void *data);
+
 #endif /* MENU_CALLBACKS_H */
