@@ -390,7 +390,7 @@ GnomeUIInfo main_menu[] = {
 
 enum {
 	FILE_POPUP_MENU_OPEN = 0,
-	FILE_POPUP_MENU_OPEN_WITH = 0,
+	FILE_POPUP_MENU_OPEN_WITH,
 	FILE_POPUP_MENU_VIEW,
 	FILE_POPUP_MENU_SEP1,
 	FILE_POPUP_MENU_ADD,
@@ -403,7 +403,8 @@ enum {
 	FILE_POPUP_MENU_DELETE,
 	FILE_POPUP_MENU_SEP3,
 	FILE_POPUP_MENU_SELECT_ALL,
-	FILE_POPUP_MENU_DESELECT_ALL
+	FILE_POPUP_MENU_DESELECT_ALL,
+	FILE_POPUP_MENU_SIZE
 };
 
 
