@@ -49,7 +49,8 @@ typedef enum {
 	FR_BATCH_ACTION_ADD_INTERACT,
 	FR_BATCH_ACTION_EXTRACT,
 	FR_BATCH_ACTION_EXTRACT_INTERACT,
-	FR_BATCH_ACTION_CLOSE
+	FR_BATCH_ACTION_CLOSE,
+	FR_BATCH_ACTION_QUIT
 } FRBatchAction;
 
 typedef struct {
@@ -183,7 +184,7 @@ typedef struct {
 	GtkWidget *      toolbar_stop;
 
 	GtkWidget *      file_popup_menu;
-	GtkWidget *      popupmenu_file[14];
+	GtkWidget *      popupmenu_file[15];
 
 	EggRecentViewGtk *recent_view;
 	EggRecentModel   *recent_model;
@@ -251,7 +252,7 @@ void       window_close                     (FRWindow      *window);
 
 /* archive operations */
 
-void       window_archive_new               (FRWindow      *window, 
+gboolean   window_archive_new               (FRWindow      *window, 
 					     const char    *filename);
 
 gboolean   window_archive_open              (FRWindow      *window, 
@@ -278,23 +279,25 @@ void       window_archive_add_with_wildcard (FRWindow      *window,
 					     const char    *include_files,
 					     const char    *exclude_files,
 					     const char    *base_dir,
+					     const char    *dest_dir,
 					     gboolean       update,
 					     gboolean       recursive,
 					     gboolean       follow_links,
-					     gboolean       same_fs,
-					     gboolean       no_backup_files,
-					     gboolean       no_dot_files,
-					     gboolean       ignore_case,
 					     const char    *password,
 					     FRCompression  compression);
 
 void       window_archive_add_directory     (FRWindow      *window,
 					     const char    *directory,
 					     const char    *base_dir,
+					     const char    *dest_dir,
 					     gboolean       update,
 					     const char    *password,
 					     FRCompression  compression);
 
+void       window_archive_add_items         (FRWindow      *window,
+					     GList         *item_list,
+					     gboolean       update);
+
 void       window_archive_remove            (FRWindow      *window,
 					     GList         *file_list,
 					     FRCompression  compression);
@@ -427,6 +430,8 @@ void       window_archive__open_add           (FRWindow      *window,
 
 void       window_archive__close              (FRWindow      *window);
 
+void       window_archive__quit               (FRWindow      *window);
+
 
 /**/
 
